"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const anchor = __importStar(require("@project-serum/anchor2.24.2"));
const anchor2_24_2_1 = require("@project-serum/anchor2.24.2");
const web3_js_1 = require("@solana/web3.js");
const _1 = require("./index.js");
const __1 = require("../index.js");
const opts = {
    preflightCommitment: "processed",
    commitment: "processed",
};
const steTestnetSecretKey = [
    14, 196, 120, 116, 89, 215, 192, 198, 118, 46, 135, 32, 175, 224, 99, 185, 39, 225, 71, 209, 134, 133, 76, 195, 101,
    50, 244, 240, 152, 194, 131, 243, 8, 80, 219, 11, 108, 145, 141, 187, 180, 131, 47, 16, 188, 147, 71, 32, 24, 213, 56,
    86, 173, 149, 247, 75, 132, 206, 175, 196, 172, 207, 173, 181,
];
const secretKey = Uint8Array.from(steTestnetSecretKey);
const keypair = web3_js_1.Keypair.fromSecretKey(secretKey);
const wallet = new anchor2_24_2_1.Wallet(keypair);
describe("supplyToEarn instructions", () => {
    let mockTestnetConnection;
    let mockReserve;
    let mockObligation;
    let mockTokenAddress;
    let provider;
    let payer;
    beforeAll(() => {
        mockTestnetConnection = new web3_js_1.Connection(__1.TESTNET_URL);
        mockReserve = new web3_js_1.PublicKey("2RbgMCDxwFn5HdrjoW2rJPcj6wStFRRPhguAgLnb9y62");
        mockObligation = new web3_js_1.PublicKey("EbAEMGNjpYfUAXJaD8MbEPoC7fgWr239JGSVpV29WdgQ");
        mockTokenAddress = "4JRe6jvgeXCcQwsxQY3StUcwnrCRKrTcWS4pHjtkpWrK";
        provider = new anchor2_24_2_1.AnchorProvider(mockTestnetConnection, wallet, opts);
        payer = provider.wallet.payer;
    });
    it("should create a supply to earn instruction correctly", async () => {
        const instruction = await (0, _1.supplyToEarnInstruction)(mockTestnetConnection, mockReserve, mockObligation, wallet.publicKey);
        // Instruction type check
        expect(instruction).toBeDefined();
        expect(instruction.keys).toBeInstanceOf(Array);
        expect(instruction.programId).toBeInstanceOf(anchor.web3.PublicKey);
        // Accounts check
        const reserveAccountInstruction = instruction.keys.find((key) => key.pubkey.equals(mockReserve));
        expect(reserveAccountInstruction).toBeDefined();
        const obligationAccountInstruction = instruction.keys.find((key) => key.pubkey.equals(mockObligation));
        expect(obligationAccountInstruction).toBeDefined();
        const ownerAccountInstruction = instruction.keys.find((key) => key.pubkey.equals(wallet.publicKey));
        expect(ownerAccountInstruction).toBeDefined();
        expect(async () => {
            const tx = new web3_js_1.Transaction();
            tx.recentBlockhash = (await mockTestnetConnection.getLatestBlockhash("finalized")).blockhash;
            tx.add(instruction);
            tx.sign(payer);
            const simulationResult = await mockTestnetConnection.simulateTransaction(tx);
            expect(simulationResult.value.err).toBeNull();
        }).not.toThrow();
    });
    it("should create a claim supply to earn reward instruction and create ata (case not have ata yet) correctly", async () => {
        const instructions = await (0, _1.claimSupplyToEarnRewardInstruction)(mockTestnetConnection, mockReserve, mockObligation, wallet.publicKey, mockTokenAddress);
        // Instruction type check
        expect(instructions).toBeDefined();
        expect(instructions).toBeInstanceOf(Array);
        expect(instructions.length).toBe(2);
        expect(async () => {
            const tx = new web3_js_1.Transaction();
            tx.recentBlockhash = (await mockTestnetConnection.getLatestBlockhash("finalized")).blockhash;
            tx.add(...instructions);
            tx.sign(payer);
            const simulationResult = await mockTestnetConnection.simulateTransaction(tx);
            expect(simulationResult.value.err).toBeNull();
        }).not.toThrow();
    });
});
